==> oidn-1.4.2.tar.gz: oidn-1.4.2/doc/downloads.md <==
Download Precompiled Intel Open Image Denoise Binary Packages
=============================================================

Prerequisites
-------------

You need a CPU with SSE4.1 support or Apple Silicon to run Intel Open Image
Denoise, and you need a 64-bit operating system as well. The TGZ/ZIP packages
contain most needed 3rd party dependencies.

Packages
--------

For Linux we provide Intel Open Image Denoise precompiled for 64-bit as a TGZ
file:

[oidn-<OIDN_VERSION>.x86_64.linux.tar.gz](https://github.com/OpenImageDenoise/oidn/releases/download/v<OIDN_VERSION>/oidn-<OIDN_VERSION>.x86_64.linux.tar.gz)

For macOS we provide Intel Open Image Denoise as a TGZ file:

[oidn-<OIDN_VERSION>.x86_64.macos.tar.gz](https://github.com/OpenImageDenoise/oidn/releases/download/v<OIDN_VERSION>/oidn-<OIDN_VERSION>.x86_64.macos.tar.gz)

For Windows we provide Intel Open Image Denoise binaries precompiled for 64-bit as a ZIP archive:

[oidn-<OIDN_VERSION>.x64.vc14.windows.zip](https://github.com/OpenImageDenoise/oidn/releases/download/v<OIDN_VERSION>/oidn-<OIDN_VERSION>.x64.vc14.windows.zip)

The source code of the latest Intel Open Image Denoise version can be downloaded here:

[oidn-<OIDN_VERSION>.src.zip](https://github.com/OpenImageDenoise/oidn/releases/download/v<OIDN_VERSION>/oidn-<OIDN_VERSION>.src.zip)
[oidn-<OIDN_VERSION>.src.tar.gz](https://github.com/OpenImageDenoise/oidn/releases/download/v<OIDN_VERSION>/oidn-<OIDN_VERSION>.src.tar.gz)

You can also access [old Intel Open Image Denoise releases](https://github.com/OpenImageDenoise/oidn/releases).

==> oidn-2.3.2.tar.gz: oidn-2.3.2/doc/downloads.md <==
Download Precompiled Intel Open Image Denoise Binary Packages
=============================================================

For Linux we provide Intel Open Image Denoise precompiled for 64-bit as a TGZ
archive:

[oidn-<OIDN_VERSION>.x86_64.linux.tar.gz](https://github.com/OpenImageDenoise/oidn/releases/download/v<OIDN_VERSION>/oidn-<OIDN_VERSION>.x86_64.linux.tar.gz)

For macOS we provide Intel Open Image Denoise precompiled for Intel processors and Apple silicon as separate TGZ archives:

[oidn-<OIDN_VERSION>.x86_64.macos.tar.gz](https://github.com/OpenImageDenoise/oidn/releases/download/v<OIDN_VERSION>/oidn-<OIDN_VERSION>.x86_64.macos.tar.gz)

[oidn-<OIDN_VERSION>.arm64.macos.tar.gz](https://github.com/OpenImageDenoise/oidn/releases/download/v<OIDN_VERSION>/oidn-<OIDN_VERSION>.arm64.macos.tar.gz)

For Windows we provide Intel Open Image Denoise binaries precompiled for 64-bit as a ZIP archive:

[oidn-<OIDN_VERSION>.x64.windows.zip](https://github.com/OpenImageDenoise/oidn/releases/download/v<OIDN_VERSION>/oidn-<OIDN_VERSION>.x64.windows.zip)

The source code of the latest Intel Open Image Denoise version can be downloaded here:

[oidn-<OIDN_VERSION>.src.zip](https://github.com/OpenImageDenoise/oidn/releases/download/v<OIDN_VERSION>/oidn-<OIDN_VERSION>.src.zip)

[oidn-<OIDN_VERSION>.src.tar.gz](https://github.com/OpenImageDenoise/oidn/releases/download/v<OIDN_VERSION>/oidn-<OIDN_VERSION>.src.tar.gz)

The TGZ/ZIP packages contain most needed 3rd party dependencies.

You can also access [old Intel Open Image Denoise releases](https://github.com/OpenImageDenoise/oidn/releases).
